# midisplitter
## Stand-alone, pure Python MIDI splitter for splitting any MIDI into individual voices

<img width="1024" height="1148" alt="midisplitter" src="https://github.com/user-attachments/assets/e2fb7984-993b-4dbd-8b22-d4a8d18787fd" />

***

## Installation

```sh
!pip install midisplitter
```

***

## Use as follows

```python
from midisplitter import split_midi

split_midi('input.mid')
```

***

### Project Los Angeles
### Tegridy Code 2026
